changeset 23783:1523f2f7832f

renamed JVMCIPrintSystemProperties to JVMCIPrintProperties
author Doug Simon <doug.simon@oracle.com>
date Wed, 05 Oct 2016 22:07:45 +0200
parents 286dce1eca9b
children 19222d463306
files jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/HotSpotJVMCIRuntime.java jvmci/jdk.vm.ci.runtime/src/jdk/vm/ci/runtime/services/JVMCICompilerFactory.java src/share/vm/compiler/compileBroker.cpp src/share/vm/jvmci/jvmci_globals.cpp src/share/vm/jvmci/jvmci_globals.hpp
diffstat 5 files changed, 15 insertions(+), 16 deletions(-) [+]
line wrap: on
line diff
--- a/jvmci/jdk.vm.ci.runtime/src/jdk/vm/ci/runtime/services/JVMCICompilerFactory.java	Wed Oct 05 11:38:45 2016 -0700
+++ b/jvmci/jdk.vm.ci.runtime/src/jdk/vm/ci/runtime/services/JVMCICompilerFactory.java	Wed Oct 05 22:07:45 2016 +0200
@@ -74,10 +74,10 @@
     public abstract JVMCICompiler createCompiler(JVMCIRuntime runtime);
 
     /**
-     * Prints a help message describing the system properties used to configure this compiler.
+     * Prints a description of the properties used to configure this compiler.
      *
      * @param out where to print the message
      */
-    public void printSystemProperties(PrintStream out) {
+    public void printProperties(PrintStream out) {
     }
 }
--- a/src/share/vm/jvmci/jvmci_globals.cpp	Wed Oct 05 11:38:45 2016 -0700
+++ b/src/share/vm/jvmci/jvmci_globals.cpp	Wed Oct 05 22:07:45 2016 +0200
@@ -74,7 +74,7 @@
   CHECK_NOT_SET(JVMCIUseFastLocking,          EnableJVMCI)
   CHECK_NOT_SET(JVMCINMethodSizeLimit,        EnableJVMCI)
   CHECK_NOT_SET(MethodProfileWidth,           EnableJVMCI)
-  CHECK_NOT_SET(JVMCIPrintSystemProperties,   EnableJVMCI)
+  CHECK_NOT_SET(JVMCIPrintProperties,         EnableJVMCI)
   CHECK_NOT_SET(TraceUncollectedSpeculations, EnableJVMCI)
 
 #ifndef PRODUCT
--- a/src/share/vm/jvmci/jvmci_globals.hpp	Wed Oct 05 11:38:45 2016 -0700
+++ b/src/share/vm/jvmci/jvmci_globals.hpp	Wed Oct 05 22:07:45 2016 +0200
@@ -52,8 +52,8 @@
   product(bool, UseJVMCICompiler, false,                                    \
           "Use JVMCI as the default compiler")                              \
                                                                             \
-  product(bool, JVMCIPrintSystemProperties, false,                          \
-          "Prints system properties used by the JVMCI compiler")            \
+  product(bool, JVMCIPrintProperties, false,                                \
+          "Prints properties used by the JVMCI compiler")                   \
                                                                             \
   product(bool, UseJVMCIClassLoader, true,                                  \
           "Load JVMCI classes with separate class loader")                  \
--- a/jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/HotSpotJVMCIRuntime.java	Wed Oct 05 11:38:45 2016 -0700
+++ b/jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/HotSpotJVMCIRuntime.java	Wed Oct 05 22:07:45 2016 +0200
@@ -92,9 +92,9 @@
         // @formatter:off
         Compiler(String.class, null, "Selects the system compiler."),
         // Note: The following one is not used (see InitTimer.ENABLED). It is added here
         // so that -XX:+JVMCIPrintSystemProperties shows the option.
         InitTimer(Boolean.class, false, "Specifies if initialization timing is enabled."),
-        PrintConfig(Boolean.class, false, "Prints VM configuration available via JVMCI and exits."),
+        PrintConfig(Boolean.class, false, "Prints VM configuration available via JVMCI."),
         TraceMethodDataFilter(String.class, null,
                         "Enables tracing of profiling info when read by JVMCI.",
                         "Empty value: trace all methods",
@@ -174,12 +174,12 @@
         }
 
         /**
-         * Prints system properties used to configure shared JVMCI code.
+         * Prints a description of the properties used to configure shared JVMCI code.
          *
          * @param out stream to print to
          */
-        public static void printSystemProperties(PrintStream out) {
-            out.println("[JVMCI system properties]");
+        public static void printProperties(PrintStream out) {
+            out.println("[JVMCI properties]");
             int typeWidth = 0;
             int nameWidth = 0;
             Option[] values = values();
@@ -263,7 +263,6 @@
     @SuppressWarnings("unused") private final String[] trivialPrefixes;
 
     @SuppressWarnings("try")
-    @SuppressFBWarnings(value = "DM_EXIT", justification = "PrintFlags is meant to exit the VM")
     private HotSpotJVMCIRuntime() {
         compilerToVm = new CompilerToVM();
 
@@ -309,10 +308,10 @@
             compilationLevelAdjustment = config.compLevelAdjustmentNone;
         }
 
-        if (config.getFlag("JVMCIPrintSystemProperties", Boolean.class)) {
+        if (config.getFlag("JVMCIPrintProperties", Boolean.class)) {
             PrintStream out = new PrintStream(getLogStream());
-            Option.printSystemProperties(out);
-            compilerFactory.printSystemProperties(out);
+            Option.printProperties(out);
+            compilerFactory.printProperties(out);
         }
 
         if (Option.PrintConfig.getBoolean()) {
@@ -92,9 +92,9 @@
         Compiler(String.class, null, "Selects the system compiler."),
         // Note: The following one is not used (see InitTimer.ENABLED). It is added here
-        // so that -XX:+JVMCIPrintSystemProperties shows the option.
+        // so that -XX:+JVMCIPrintProperties shows the option.
         InitTimer(Boolean.class, false, "Specifies if initialization timing is enabled."),
--- a/src/share/vm/compiler/compileBroker.cpp	Wed Oct 05 11:38:45 2016 -0700
+++ b/src/share/vm/compiler/compileBroker.cpp	Wed Oct 05 22:07:45 2016 +0200
@@ -944,8 +944,8 @@
 #if INCLUDE_JVMCI
   if (EnableJVMCI) {
     JVMCICompiler* jvmci = new JVMCICompiler();
-    if (JVMCIPrintSystemProperties) {
-      // Initialize JVMCI eagerly if JVMCIPrintSystemProperties is enabled.
+    if (JVMCIPrintProperties) {
+      // Initialize JVMCI eagerly if JVMCIPrintProperties is enabled.
       // The JVMCI Java initialization code will read this flag and
       // do the printing if it's set.
       JVMCIRuntime::ensure_jvmci_class_loader_is_initialized();